package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````_!<``#0````XP0```````#0`(``)
M`"@`&P`:``8````T````-````#0````@`0``(`$```0````$`````P```%0!
M``!4`0``5`$``!,````3````!`````$````!````````````````````2*\`
M`$BO```%`````!````$```"HO0``J,T``*C-``!H`@``K!(```8`````$```
M`@```+"]``"PS0``L,T``"`!```@`0``!@````0````$````:`$``&@!``!H
M`0``1````$0````$````!````%#E=&0TH0``-*$``#2A``#T````]`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DJ+T`
M`*C-``"HS0``6`(``%@"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````#`````@`````````$````%`````,```!'
M3E4`,B"G\6[@GD1C:!/_8I;B^AXAY_\1````2P````@````(`````!`0!"5`
M!(`H`0`!H(8`@(`!```+*`0).*`218H$"`@`````2P```$\```!3````5```
M`%H```!;````7````%X```!?`````````&$```!C````9````&4`````````
M`````.K3[PYNQ=\?SMY'+6M_FGPNQ9NVU&34?"#_Y`ZYC?$.V7%8'.)'Q@&R
M`8MOK$OCP,+E/RRZXY)\^Z%L8&L)0]9GK\QF0D75[(D'<-,-%.*>,F+;[=O-
MXYX,.I<+6>CM['^IG)OAIP(*H^#[20`````````````````````8`@``````
M```````2````C`(`````````````$@```'<"`````````````!(````,`0``
M```````````2````DP``````````````$@````$!`````````````!$```#*
M`@`````````````2````DP$`````````````$@```+4"`````````````!(`
M```B`0`````````````2````$0``````````````(````'T"````````````
M`!(```#K`@`````````````2````&0,`````````````$@```$@"````````
M`````!(```#W`0`````````````2````4P$`````````````$@```+0`````
M`````````!(```!#`0`````````````2````-0$`````````````$@```%T#
M`````````````!(````,`P`````````````2````!`(`````````````$@``
M`/\!`````````````!(````@```````````````@````L0$`````````````
M$@```!$!`````````````!(```#8`@`````````````2````3P,`````````
M````$@```#P``````````````"````#C`@`````````````2````5@``````
M````````$@```(,!`````````````!(```!S```````````````2````\```
M````````````$@```(0``````````````!(````@`P`````````````2````
M]0(`````````````$0```,,"`````````````!(```"A`@`````````````2
M````<`(`````````````$@```#T$`````````````!(```#4````````````
M```2````_`(`````````````$@```'$#`````````````!$```!U`0``````
M```````2````9P(`````````````$@```"D"`````````````!(```!G`0``
M```````````2````J`(`````````````$@```*H!`````````````!(````6
M`0`````````````2````>0,`````````````$@```*\"`````````````!(`
M``!P`P`````````````A````F@(`````````````$@````,#````````````
M`!(```!'`P`````````````2````GP``````````````$@```)X!````````
M`````!(````Y`P`````````````2````;P,`````````````$0```(4"````
M`````````!(```!?`@`````````````2````\`$`````````````$@```.,`
M`````````````!$```"\`0`````````````1````7`$`````````````$@``
M`&0``````````````!(```"3`@`````````````2````5@,`````````````
M$@```"H#`````````````"(```!:`@`````````````2````P@``````````
M````$@```-@#``#D80```````!(`#P!&!```L&```&\````2``X`=P0``+!/
M``!A#0``$@`.`&H#``#`%0``/`(``!(`#@"P`P``$$D```4````2``X`Y0,`
M`"!=``"&`P``$@`.`)8$```@20``!0(``!(`#@!A!```O!$````````2``L`
MGP,``!#0````````$``8`,$#```P2P``*@```!(`#@#[`P``($X``'8````2
M``X`.0(``/QA```$````$0`0`%\$``"P1P``.P```!(`#@"K`P``5.``````
M```0`!@`A`0``.!.``#'````$@`.`%($````T````````!``%P`?!```8$L`
M`.<````2``X`F`,``!#0````````$``7`*,$```,T```!````!$`%P#.`P``
MP&$```(````2``X`6`0``/P7````````$@`.`&<$``!@80``70```!(`#@!4
M!````-`````````@`!<`W@,``/AA```$````$0`0`"L$``"@3@``-````!(`
M#@`)!```4$@``+D````2``X`K00``%!,``#$`0``$@`.``!L:6)P97)L+G-O
M+C4N,C8`7U]G;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A
M8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T
M`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD
M=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R
M;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R
M;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C
M=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI
M8F1L+G-O+C(`;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!O<&5N-C0`;'-E
M96LV-`!R96%D`'!T:')E861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO
M;@!C;&]S90!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A
M=&9O<FL`97AI=`!S=')N8VUP`&-L;W-E9&ER`'5N;&EN:P!M:V1I<@!R96%L
M;&]C`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R
M`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L
M>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L
M:6YK`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L
M:7IE`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB
M8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?7W-T86-K7V-H:U]F86EL`&QI8F-R
M>7!T+G-O+C$`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`<&%R7V-U<G)E;G1?
M97AE8P!P87)?8F%S96YA;64`7U]L:6)C7V-S=5]F:6YI`%]F<%]H=P!84U])
M;G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U
M:60`<&%R7V-L96%N=7``7U]D871A7W-T87)T`'AS7VEN:70`7U]L:6)C7V-S
M=5]I;FET`'!A<E]M:W1M<&1I<@!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN
M9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C$N,P!'3$E"
M0U\R+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXR`$=,24)#7S(N,RXT`$=,24)#
M7S(N,`````(``P`#``````````0````$```````#``4``P`&``<`````````
M```#``0``@`"```````#``4``P````,```````````````4``P`#``,``P`#
M`````P`#`````P`"`````P`#````"``#``,``P`#``,```````0``P`#``,`
M!P````````````,``P`)``,````!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``8`+P(``!````!P````
M<Q]I"0``"0"Z!```$````!1I:0T```@`Q@0``!````!R&6D)```&`-`$```0
M````$FEI#0``!0#<!```$````'09:0D```0`Y@0``!`````0:6D-```#`/($
M`````````0`"`.`!```0`````````!)I:0T```<`W`0``!`````0:6D-```"
M`/($````````J,T```@```"LS0``"````/S/```(````!-````@````,T```
M"````,S/```&!@``T,\```8*``#4SP``!@L``-C/```&&0``W,\```8>``#@
MSP``!B$``.3/```&(@``Z,\```8F``#LSP``!BT``/#/```&0@``],\```9#
M``#XSP``!D@``-S.```'`0``X,X```<"``#DS@``!P,``.C.```'!```[,X`
M``<%``#PS@``!P<``/3.```'"```^,X```<)``#\S@``!PP```#/```'#0``
M!,\```<.```(SP``!P\```S/```'$```$,\```<1```4SP``!Q(``!C/```'
M$P``',\```<4```@SP``!Q4``"3/```'%@``*,\```<7```LSP``!Q@``##/
M```'&@``-,\```<;```XSP``!QP``#S/```''0``0,\```<?``!$SP``!R``
M`$C/```'(P``3,\```<D``!0SP``!R4``%3/```')P``6,\```<H``!<SP``
M!RD``&#/```'*@``9,\```<K``!HSP``!RP``&S/```'+@``<,\```<O``!T
MSP``!S```'C/```',0``?,\```<R``"`SP``!S,``(3/```'-```B,\```<U
M``",SP``!S8``)#/```'.```E,\```<Y``"8SP``!SH``)S/```'.P``H,\`
M``<\``"DSP``!ST``*C/```'/P``K,\```=```"PSP``!T$``+3/```'1```
MN,\```=%``"\SP``!T8``,#/```'1P``Q,\```=)``#(SP``!TH``%.#[`CH
M>P8``('#"[T``(N#!`$``(7`=`7HU@,``(/$"%O#`/^S!````/^C"```````
M``#_HPP```!H`````.G@_____Z,0````:`@```#IT/____^C%````&@0````
MZ<#_____HQ@```!H&````.FP_____Z,<````:"````#IH/____^C(````&@H
M````Z9#_____HR0```!H,````.F`_____Z,H````:#@```#I</____^C+```
M`&A`````Z6#_____HS````!H2````.E0_____Z,T````:%````#I0/____^C
M.````&A8````Z3#_____HSP```!H8````.D@_____Z-`````:&@```#I$/__
M__^C1````&AP````Z0#_____HT@```!H>````.GP_O___Z-,````:(````#I
MX/[___^C4````&B(````Z=#^____HU0```!HD````.G`_O___Z-8````:)@`
M``#IL/[___^C7````&B@````Z:#^____HV````!HJ````.F0_O___Z-D````
M:+````#I@/[___^C:````&BX````Z7#^____HVP```!HP````.E@_O___Z-P
M````:,@```#I4/[___^C=````&C0````Z4#^____HW@```!HV````.DP_O__
M_Z-\````:.````#I(/[___^C@````&CH````Z1#^____HX0```!H\````.D`
M_O___Z.(````:/@```#I\/W___^CC````&@``0``Z>#]____HY````!H"`$`
M`.G0_?___Z.4````:!`!``#IP/W___^CF````&@8`0``Z;#]____HYP```!H
M(`$``.F@_?___Z.@````:"@!``#ID/W___^CI````&@P`0``Z8#]____HZ@`
M``!H.`$``.EP_?___Z.L````:$`!``#I8/W___^CL````&A(`0``Z5#]____
MH[0```!H4`$``.E`_?___Z.X````:%@!``#I,/W___^CO````&A@`0``Z2#]
M____H\````!H:`$``.D0_?___Z/$````:'`!``#I`/W___^CR````&AX`0``
MZ?#\____H\P```!H@`$``.G@_/___Z/0````:(@!``#IT/S___^CU````&B0
M`0``Z<#\____H]@```!HF`$``.FP_/___Z/<````:*`!``#IH/S___^CX```
M`&BH`0``Z9#\____H^0```!HL`$``.F`_/___Z/H````:+@!``#I</S___^C
M[````&C``0``Z6#\____H_````!HR`$``.E0_/___Z/T````:-`!``#I0/S_
M__^C^````&C8`0``Z3#\____HP0!``!FD/^C*`$``&:0C4PD!(/D\/]Q_%6)
MY5=64U&)S^AH`@``@</XN```@^PLBT$$B474BT$(B4709:$4````B47D,<"-
M1=!0C4744%'H6O___XN#``$``(/$#%!0_[,4`0``Z!1+``"+@R`!``"#Q!"`
M.``/A"(!``"+L_P```"#[`S_-NCB_/__@(C^`@```EK_-NC3_/__@(C^`@``
M`8L'@\00@\`%/?___S\/AU4!``"#[`S!X`)0Z(W^__^+==2+#X/$$(F#=!$`
M`,>#>!$```0```"+%H/Y`8D0C9,`E?__B5`$BY,\`0``B5`(C9,#E?__B5`,
M?A>Z`0```(UT)@"+/):)?)`,@\(!.=%U\H/L#,=$B`P`````@\$#:@!0C8,@
M>?__45#_LX`1``#H9OO__X/$((7`B<8/A*T```"#[`S_LX`1``"-?>#H6/W_
M_XV#T)/__XGZZ`LJ``"#Q!"%P'1M@^P,_[.`$0``Z/;Z___H8?S__X/$$(GP
MBTWD93,-%`````^%J0```(UE\%E;7E]=C6'\P^CK^___A<")@X`1```/A(\`
M``"#[`Q0Z$3\__^+L_P```!9_S;HIOO__X/$$,:`<04```#IJ_[__XN#?!$`
M`(7`=#V#[`Q0Z!1)``"#Q!#I>/___X/L#/^S@!$``.@.^___@\00B<;I.___
M_U!0C8."D____[,D`0``4.@@_?__C8.%D___B?KH0RD``(7`B8-\$0``#X0Q
M____ZZ;HWDD``(/L#&H!Z)3]__\Q[5Z)X8/D\%!44N@B````@</$M@``C8/P
MDO__4(V#D)+__U!15O^S+`$``.C3^O__](L<),-FD&:09I!FD&:09I!FD(L<
M),-FD&:09I!FD&:09I#HY````('">[8``(V*0`$``(V"0`$``#G(=!V+@@@!
M``"%P'0358GE@^P44?_0@\00R<.0C70F`//#C;8`````Z*0```"!PCNV``!5
MC8I``0``C8)``0``*<B)Y5/!^`*)PX/L!,'K'P'8T?AT%(N2#`$``(72=`J#
M[`A04?_2@\00BUW\R<.)]HV\)P````!5B>53Z%?___^!P^>U``"#[`2`NU`!
M````=2>+@R@!``"%P'01@^P,_[,T`0``Z*7\__^#Q!#H-?___\:#4`$```&+
M7?S)PXGVC;PG`````%6)Y5WI5____XL4),-FD)!55XUH.%93@>P,`P``C4PD
M>(E$)%2)="0098L=%````(F<)/P"```QVXE,)`B)?"04C;0F`````(M4G0"+
M1)T$QT39!`````#'1-D,`````,=$)`0`````#\J)!"2)%-F)PL'H&,'J"('B
M`/\```G0BQ0DB<>+!"3!XAC!X`@)UR4``/\`"?B)1-D(@\,"@_L0=:6+1"0(
MC90D>`(``(D4)(G%D(UT)@"+56B+16R#Q0@S53@S13PS50@S10PS5?@S1?S'
M17P`````B<>)T(G1#ZSX'P'1"<&)37@[+"1UR(M<)%2+4PR+2QR+,XM[!(M#
M"(E4)!R+4Q2)3"0,BTLDB40D&(M#$(E4)`2+4QB)3"1<B7PD%(D$)(E4)`B+
M4R"+7"0$B50D6(GRP>8%B=&)]8MT)%@/K/D;BWPD"(E4)!`)S0-T)'B)Z(GQ
MBW0D#('!F7F"6@'(BPPD,=XC="0<,<^+3"08B70D("'/B?Z+?"0(,?X!\(E$
M)""+?"08BVPD'(L$)(M4)`3'1"0D`````(GYB?['1"0\``````^L[@+!X1Z)
MQXM$)!")S8M,)`C'1"0L``````GU`XPD@````(G6B6PD,(EL)#C'1"1$````
M`('!F7F"6B-T)!0Q[R''B70D*(G^BSPD,?Z+?"0D`?&+="0@B?V)\(GWP>`%
MB40D*(MT)"@/K.\;BVPD%`G^BWPD$(GPBS0D`<B)1"0HB?F)^`^LZ`+!X1Z+
M?"0$B<V+3"0P"<4#M"2(````$[PDC````(EL)$")\(MT)"`%F7F"6HGZBWPD
M.(/2`#'I,=LASL=$)$P`````QT0D/``````Q]XG^B=^+7"0X`<:+1"0H$=>+
M5"0LB70D,(E\)#2+?"0DB<;'1"0T``````^LT!O!Y@6+5"0LB<$)\8MT)"")
MR`-$)#")\0^L_@+!X1Z)1"0PBWPD,`GQ`YPDD````(E,)&")3"1(B=@%F7F"
M6C'-(VPD*#-L)$")Z8ML)#0!P8GXP>`%B40D((MT)"`/K.\;"?Z)\`'(,?^)
MQHM$)"B)P<'A'@^LT`*)S8M4)$"+3"1@"<4#E"28````B6PD.(EL)$")T`69
M>8):,>DC3"0PBVPD2(M4)#3'1"0D`````,=$)#0`````QT0D1``````QS8GI
M`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D*`ML)"B)Z(ML)$`!R(E$)""+1"0P
MB<$/K-`"P>$>BU0D3`G!BT0D2`.$)*`````3E"2D````B4PD,(E,)$@%F7F"
M6H/2`#'-,=LA]3-L)#B)Z0'!BT0D(!'3BU0D)(E,)"B)7"0LQT0D+`````")
MP<'A!8E,)$")T8ML)$")P@^LRAN)\0G5B>@#1"0HP>$>#ZS^`HG-"?6)1"0H
MB6PD0(M<)#@#G"2H````BW0D/!.T)*P```"+3"1(B=B)\HMT)"`%F7F"6H/2
M`#'I,=N)WR'.,W0D,`'&BT0D*!'7BU0D+(ET)#B)?"0\QT0D/`````")Q@^L
MT!O!Y@6+5"0DQT0D)`````")P0GQB<@#1"0X,?^)QHM$)"")P0^LT`+!X1Z+
M5"0L"<&+1"0P`X0DL````(E,)#B)3"1(!9EY@EHQS2-L)"@S;"1`B>D!P8GP
MP>`%B40D((GPBVPD(`^L^!N)1"0P"VPD,(GH`<B)1"0@BT0D*(G!P>$>#ZS0
M`HG-"<6);"0PBU0D0`.4)+@```"+3"1$$XPDO````,=$)#0`````QT0D1```
M``")T`69>8):B<J+3"1(@](`B40D*#';B50D+(M4)#@QZ2'Q,<J)T`-$)"B)
MVA-4)"R)1"0HBT0D((E4)"R+5"0DQT0D+`````")P<'A!8E,)$")T8G"#ZS*
M&XM,)$")5"1("TPD2(G(`T0D*(GQ#ZS^`L'A'@GQB40D*(M$)#@#A"3`````
MB4PD0(E,)$@%F7F"6C'-(VPD(#-L)#"+?"0HBU0D),=$)#P`````QT0D)```
M``#'1"0T`````(GIBVPD+`'!B?C!X`6)1"0XBW0D.`^L[QL)_HGP`<@Q_XG&
MBT0D((G!P>$>#ZS0`HG-BU0D,(M,)$@)Q0.4),@```");"0XB6PD2(G0BU0D
M+`69>8):,>DC3"0HBVPD0#'-B>D!P8GPP>`%B40D((GPBVPD(`^L^!N)1"0P
M"VPD,(GH`<B)1"0@BT0D*(G!#ZS0`L'A'HM4)$0)P8M$)$`#A"30````$Y0D
MU````(E,)#")3"1@BVPD2,=$)$0`````!9EY@EJ#T@`QS3';(?4S;"0XB>D!
MP8M$)"`1TXM4)"2)3"0HB5PD+(M<)#B)P<=$)"P`````P>$%B4PD0(G1BVPD
M0(G"#ZS*&XGQ"=6)Z`-$)"C!X1X/K/X"B<V+3"1@"?4#G"38````BW0D/!.T
M)-P```")1"0HB6PD0(G8B?*+="0@!9EY@EJ#T@`QZ3';B=\ASC-T)#`!QHM$
M)"@1UXM4)"R)="0XB7PD/,=$)#P`````B<8/K-`;P>8%BU0D)(G!"?&)R`-$
M)#@Q_XG&BT0D((G!#ZS0`L'A'@G!B4PD.(M$)#`#A"3@````B4PD2(M4)"S'
M1"0D`````,=$)#0`````!9EY@EHQS2-L)"@S;"1`B>D!P8GPP>`%B40D((GP
MBVPD(`^L^!N)1"0P"VPD,(GH`<B)1"0@BT0D*(G!P>$>#ZS0`HG-BU0D0(M,
M)$0)Q0.4).@````3C"3L````B6PD,(G0!9EY@EJ)RHM,)$B#T@")1"0H,=N)
M5"0LBU0D.#'I(?$QRHG0`T0D*(G:$U0D+(E$)"B+1"0@B50D+(M4)"2)P<'A
M!8E,)$")T8G"#ZS*&XM,)$"+7"0XB50D2`M,)$C'1"0L`````(M4)"3'1"1$
M`````,=$)#P`````B<B)\0-$)"@/K/X"P>$>"?$#G"3P````B40D*(M\)"B)
M3"1(B4PD0(G8!9EY@EHQS2-L)"`S;"0PB>F+;"0L`<&)^,'@!8E$)#B+="0X
M#ZSO&PG^B?`!R#'_B<:+1"0@B<'!X1X/K-`"B<V+5"0PBTPD2`G%`Y0D^```
M`(EL)#B);"1(B=`%F7F"6C'I(TPD*(ML)$`QS8GI`<&)\,'@!8E$)"")\`^L
M^!N)1"0PBVPD(`ML)#"+5"0LQT0D)`````#'1"0T`````(GHBVPD2`'(B40D
M((M$)"B)P0^LT`+!X1Z+5"1$QT0D1``````)P8M$)$`#A"0``0``$Y0D!`$`
M`(E,)&")3"0P!9EY@EJ#T@`QS3';(?4S;"0XB>D!P8M$)"`1TXM4)"2)3"0H
MB5PD+(M<)#B)P<=$)"P`````P>$%B4PD0(G1BVPD0(G"#ZS*&XM,)&`)U8GR
MB>@#1"0HP>(>#ZS^`HG5"?4#G"0(`0``B40D*(EL)$");"1@BW0D((M4)"R)
MV`69>8):,>DASC-T)#")\0'!BT0D*(G&#ZS0&\'F!8M4)"3'1"0D`````(E$
M)#B+;"0XBT0D(`GU`>DQ_XML)&")SHE,)$B)P<'A'@^LT`*)RXM4)#`)PP.4
M)!`!``")7"0PB="+5"1$!9EY@EHQW2-L)"@S;"1`BUPD+(GI`<&)\,'@!8E$
M)"")\(ML)"`/K/@;B40D.`ML)#@!Z8E,)&")3"0@BTPD*(G(P>`>#ZS9`HG%
MBT0D0`G-`X0D&`$``(M,)#`3E"0<`0``B6PD.`6AZ]EN@](`,>F+;"1(,=O'
M1"0T`````#'-B>D!P8M$)"`1TXM4)"2)3"0HB5PD+(GSQT0D+`````")P<'A
M!8E,)$")T8ML)$")P@^LRAN+3"0H"=6)\@'IP>(>B=6+E"0@`0``B4PD2`^L
M^P*)3"0HBTPD,`G=@<*AZ]ENBUPD+(G0B6PD0(M4)"0!R#-L)#B)Z8ML)&`Q
MS8M,)"B)[@'&B<C!X`6)1"0PBT0D((ML)#`/K-D;B?,)S8G!`>O!X1X/K-`"
MB<V+E"0H`0``B5PD,`G%BT0D.(E<)&")[XML)$"!PJ'KV6Z)?"0X`=`Q_8M\
M)#")[HML)$@Q]8GIBVPD-`'!B?C!X`6)1"0@BW0D(`^L[QN+1"0HBU0D+`G^
MQT0D)`````#'1"0L``````'QB4PD2(E,)"")P<'A'@^LT`*)S8N,)#`!``"+
M5"0D"<6+1"1`B>Z+;"0X@<&AZ]ENB70D0`'(,?6)[HML)&`Q]8GI`<&+1"0@
MB<8/K-`;P>8%BU0D-(E$)"B+;"0HBT0D,`GU`>DQ_XG.B4PD8(G!P>$>#ZS0
M`HG+BY0D.`$```G#BT0D.(G=B5PD.(M<)$"!PJ'KV6X!T(M4)"0QZXML)$@Q
MW8GI`<&)\,'@!8E$)"B)\(ML)"@/K/@;B40D,`ML)#"+1"0@`>F)3"1(B4PD
M*(G!P>$>#ZS0`HG-"<6);"0PBY0D0`$``(N,)$0!``"+1"1`BVPD.('"H>O9
M;H/1`(G+B=$QT@'($=HS;"0PB40D((E4)"2+5"1@,=N)V8M$)"B+G"1(`0``
M,>H#5"0@$TPD)(E4)""+5"0LB4PD)(G!QT0D)`````#!X06)3"1`B=&+;"1`
MB<*+1"0X#ZS*&XM,)"`)U8M4)"0!Z8E,)"")3"1@B?'!X1X/K/X"B<T)]8'#
MH>O9;HGOBVPD,`'8B7PD.#']B>Z+;"1(,?6)Z0'!BT0D((G+B<8/K-`;P>8%
MB40D0(ML)$"+1"0H"?4!ZXG!,?^)7"1(BU0D+,'A'HG>QT0D+``````/K-`"
MBY0D4`$```G!BT0D,(G-BTPD.('"H>O9;HEL)$`!T(M4)"0QZ8ML)&`QS8GI
M`<&)V,'@!8E$)"B)V(ML)"@/K/@;B40D,`ML)#"+1"0@`>F)3"0HB4PD8(G!
MP>$>#ZS0`HN4)%@!``")S8N,)%P!```)Q8M$)#B);"0PBVPD0('"H>O9;H/1
M`(G+B=$QT@'($=HS;"0PB40D((E4)"2+5"1(,=N)V8M$)"@QZ@-4)"`33"0D
MB50D((M4)"R)3"0DB<'!X06)3"0XB=&+;"0XB<*+G"1@`0``BT0D0`^LRAN+
M3"0@QT0D)``````)U8M4)"0!Z8E,)$B)3"0@B?'!X1X/K/X"B<T)]8'#H>O9
M;HGOBVPD,`'8B7PD.#']B>Z+;"1@,?6)Z0'!BT0D((G&#ZS0&\'F!8M4)"S'
M1"0L`````(E$)$"+;"1`BT0D*`GU`>DQ_XG.B4PD8(G!P>$>#ZS0`HG+BY0D
M:`$```G#BT0D,(G=B5PD0(M<)#B!PJ'KV6X!T(M4)"0QZXML)$@QW8GI`<&)
M\,'@!8E$)"B)\(ML)"@/K/@;B40D,`ML)#"+1"0@`>F)3"1(B4PD*(G!P>$>
M#ZS0`HG-"<6);"0PBY0D<`$``(N,)'0!``"+1"0XBVPD0('"H>O9;H/1`(G+
MB=$QT@'($=HS;"0PB40D((E4)"2+5"1@,=N)V8M$)"B+G"1X`0``,>H#5"0@
M$TPD)(E4)""+5"0LB4PD)(G!QT0D)`````#!X06)3"0XB=&+;"0XB<*+1"1`
M#ZS*&XM,)"`)U8M4)"0!Z8E,)"")3"1@B?'!X1X/K/X"B<T)]8'#H>O9;HGO
MBVPD,`'8B7PD.#']B>Z+;"1(,?6)Z0'!BT0D((G+B<8/K-`;P>8%B40D0(ML
M)$"+1"0H"?4!ZXG!,?^)7"1(BU0D+,'A'HG>QT0D+``````/K-`"BY0D@`$`
M``G!BT0D,(G-BTPD.('"H>O9;HEL)$`!T(M4)"0QZ8ML)&`QS8GI`<&)V,'@
M!8E$)"B)V(ML)"@/K/@;B40D,`ML)#"+1"0@`>F)3"0HB4PD8(G!P>$>#ZS0
M`HN4)(@!``")S8N,)(P!```)Q8M$)#B);"0PBVPD0('"H>O9;H/1`(G+B=$Q
MT@'($=HS;"0PB40D((E4)"2+5"1(,=N)V8M$)"@QZ@-4)"`33"0DB50D((M4
M)"R)3"0DB<'!X06)3"0XB=&+;"0XB<*+G"20`0``BT0D0`^LRAN+3"0@QT0D
M)``````)U8M4)"0!Z8E,)"")3"0XB?'!X1X/K/X"B<T)]8'#H>O9;HGOBVPD
M,`'8B7PD0#']B>Z+;"1@,?6)Z0'!BT0D((G&#ZS0&\'F!8M4)"S'1"0L````
M`(E$)$B+;"1(BT0D*`GU`>DQ_XG.B4PD8(G!P>$>#ZS0`HN4))@!``")RXN,
M))P!```)PXM$)#")W8'"H>O9;HEL)$B#T0")RXG1,=(!R!':BUPD0#'KBVPD
M.#'=,=N)Z0'!B?`1T\'@!3'2B40D*(GPBVPD*`^L^!N)1"0P"VPD,(M$)"`!
MZ1'3B<J)P8E<)&R)5"1HP>$>B50D*(M4)"2)S8N,)*0!``#'1"0T``````^L
MT`*+E"2@`0``"<6+1"1`B6PD.(ML)$B!PJ'KV6Z#T0")RXG1,=(!R!':,VPD
M.(E$)"")5"0DBU0D8#';B=F+1"0HBYPDJ`$``#'J`U0D(!-,)"2)5"0@BU0D
M+(E,)"2)P<'A!8E,)#")T8ML)#")PHM$)$@/K,H;BTPD(`G5`>F)3"0PB4PD
M0(GQP>$>#ZS^`HG-BWPD,`GU@<.AZ]EN`=B+7"0XB6PD8#'KBVPD:#'=B>F+
M;"0T`<&)^,'@!8E$)""+="0@#ZSO&PG^B?`!R(E$)""+1"0HBU0D+(MT)&"+
M?"1`QT0D)`````")P<=$)"P`````QT0D3``````/K-`"P>$>BY0DL`$``(GS
MB<W'1"0\``````G%BT0D.('"H>O9;HEL)$@!T#'KBU0D)#'?BYPDO`$``(GY
M`<&+1"0@P>`%B40D*(M$)""+?"0H#ZS0&XM4)#2)1"0X"WPD.(GX`<B)1"0H
MBT0D,(G!#ZS0`L'A'@G!B?")SXE,)#B+C"2X`0``@<'<O!N/@],`,=(!R(M,
M)$@1V@G](VPD(#';(?F)S@GNB?$!P8M$)"@1TXM4)"R)3"0PB5PD-(G!P>$%
MB4PD0(G1BVPD0(G"#ZS*&PG5B>@#1"0PBU0D)#';BW0D2,=$)#0`````QT0D
M1`````")1"0PBT0D((G!P>$>#ZS0`HG-B?F)^@G%BT0D*`GI(>J);"1`(<B)
MQPG7`[0DP`$``(GYBWPD3!.\),0!``#'1"1,`````(GPB<X%W+P;CXGZB=^#
MT@`!QHM$)#`1UXM4)#2)="0@B7PD)(G&#ZS0&\'F!8M4)"R)P0GQB<@#1"0@
M,?^)QHM$)"B)P0^LT`+!X1X)P8M$)#B)R@G-B4PD2"-L)#")3"1@BTPD0"'1
M"<T#A"3(`0``B>D%W+P;CP'!B?#!X`6)1"0@B?`/K/@;B40D*(ML)"`+;"0H
MBU0D-,=$)"0`````QT0D-`````#'1"0\`````(GH`<@QVXE$)""+1"0PB<'!
MX1X/K-`"BU0D8(G-"<6);"0P">J)T(M4)$@A\"'J"="+5"1$B<&+1"1``X0D
MT`$``!.4)-0!```%W+P;CX/2``'!BT0D(!'3BU0D)(E,)"B)7"0LQT0D+```
M``")P<'A!8E,)#B)T8G"#ZS*&XM,)#B)5"1`"TPD0(G(`T0D*(GQP>$>B40D
M*(GP#ZSX`HM\)#`)P0G-(VPD((E,)#@ASXE,)&"+="1(BU0D),=$)$0`````
M"?T#M"38`0``BWPD*(GIBVPD+(GP!=R\&X\!P8GXP>`%B40D0(MT)$`/K.\;
M"?Z)\`'(,?\QVXG&BT0D((G!P>$>#ZS0`HG-BU0D8`G%BT0D*(EL)$`)ZB'0
MBU0D."'J"="+5"0TQT0D-`````")P8M$)#`#A"3@`0``$Y0DY`$```7<O!N/
M@](``<&)\!'3P>`%B4PD((G!B?"+5"0L#ZSX&XE<)"3'1"0D`````(E$)#`+
M3"0PB<@#1"0@,=N)1"0@BT0D*(G!#ZS0`L'A'@G!B<H)S8E,)#")3"1(BTPD
M0"'UBT0D."'1BU0D/,=$)#P`````"<T#A"3H`0``$Y0D[`$``(GI!=R\&X^#
MT@`!P8M$)"`1TXM4)"2)3"0HB5PD+,=$)"P`````B<'!X06)3"0XB=&+;"0X
MB<(/K,H;B?$)U8M4)$B)Z`-$)"C!X1Z)S3';B40D*(GPBW0D0`^L^`()Q8M$
M)"`)ZHEL)#@AT(M4)#")QR'J"=<#M"3P`0``B?F+?"1$$[PD]`$``(GPB<X%
MW+P;CXGZB=^#T@`!QHM$)"@1UXM4)"R)="1`B7PD1(G&#ZS0&\'F!8G!"?&)
MR`-$)$`Q_XG&BT0D((M4)"3'1"0D`````,=$)$0`````QT0D-`````")P0^L
MT`+!X1X)P8M$)#")RHE,)$")3"1("<V+3"0X(VPD*"'1BU0D+`G-`X0D^`$`
M`(GI!=R\&X\!P8GPP>`%B40D((GPBVPD(`^L^!N)1"0P"VPD,(GH`<@QVXE$
M)""+1"0HB<'!X1X/K-`"BU0D2(G-"<6);"0P">J)T(M4)$`A\"'J"="+5"0\
MB<&+1"0X`X0D``(``!.4)`0"```%W+P;CX/2``'!BT0D(!'3BU0D)(E,)"B)
M7"0LB<'!X06)3"0XB=&)P@^LRAN)5"1(BTPD.`M,)$C'1"0L`````(M4)"3'
M1"0\`````,=$)$0`````B<@#1"0HB?'!X1Z)1"0HB?"+="1`#ZSX`HM\)#`)
MP0G-(VPD((E,)#@ASXE,)$@)_0.T)`@"``"+?"0HB>F+;"0LB?`%W+P;CP'!
MB?C!X`6)1"1`BW0D0`^L[QL)_HGP`<@Q_S';B<:+1"0@B<'!X1X/K-`"B<V+
M5"1("<6+1"0HB6PD0`GJ(="+5"0X(>H)T(M4)#2)P8M$)#`#A"00`@``$Y0D
M%`(```7<O!N/@](``<&)\!'3P>`%B4PD((G!B?")7"0D#ZSX&XE$)#`+3"0P
MBU0D+,=$)"0`````QT0D-`````")R`-$)"`QVXE$)""+1"0HB<$/K-`"P>$>
M"<&+1"0XB<J)3"0PB4PD2`G-BTPD0"'U(=&+5"0\QT0D/``````)S0.$)!@"
M```3E"0<`@``B>D%W+P;CX/2``'!BT0D(!'3BU0D)(E,)"B)7"0LQT0D+```
M``")P<'A!8E,)#B)T8ML)#B)P@^LRAN)\0G5BU0D2(GH`T0D*,'A'HG-,=N)
M1"0HB?"+="1`#ZSX`@G%BT0D(`GJB6PD."'0BU0D,(G'(>H)UXGYBWPD1`.T
M)"`"```3O"0D`@``QT0D-`````")\(G.!=R\&X^)^HG?@](``<:+1"0H$=>+
M5"0LB70D0(E\)$3'1"1$`````(G&#ZS0&\'F!8M4)"3'1"0D`````(G!"?&)
MR`-$)$`Q_XG&BT0D((G!#ZS0`L'A'@G!BT0D,(G*B4PD0(E,)$@)S8M,)#@C
M;"0H(=&+5"0L"<T#A"0H`@``B>D%W+P;CP'!B?#!X`6)1"0@B?"+;"0@#ZSX
M&XE$)#`+;"0PB>@!R#';B40D((M$)"B)P<'A'@^LT`*+5"1(B<T)Q8EL)#`)
MZHG0BU0D0"'P(>H)T(G!BT0D.`.$)#`"``"+5"0\$Y0D-`(``,=$)#P`````
M!=R\&X^#T@`!P8M$)"`1TXM4)"2)3"0HB5PD+,=$)"P`````B<'!X06)3"0X
MB=&)P@^LRAN+3"0XB50D2`M,)$B+5"0DB<@#1"0HB?'!X1Z)1"0HB?"+="1`
M#ZSX`HM\)#`)P0G-(VPD((E,)#@ASXE,)$@)_0.T)#@"``"+?"0HB>F+;"0L
MB?`%W+P;CP'!B?C!X`6)1"1`BW0D0`^L[QL)_HGP`<@Q_S';B<:+1"0@B<'!
MX1X/K-`"B<T)Q8EL)$#'1"1$`````(M4)$B+1"0H">HAT(M4)#@AZ@G0BU0D
M-(G!BT0D,`.$)$`"```3E"1$`@``!=R\&X^#T@`!P8GP$=/!X`6)3"0@B<&)
M\(M4)"P/K/@;B5PD),=$)"0`````B40D,`M,)##'1"0L`````(G(`T0D(#';
MB40D((M$)"B)P0^LT`+!X1X)P8M$)#B)R@G-B4PD*(E,)&"+3"1`(?4AT8M4
M)#P)S0.$)$@"```3E"1,`@``B>D%W+P;CX/2``'!BT0D(!'3BU0D)(E,)#")
M7"0TB<'!X06)3"0XB=&+;"0XB<*)\,=$)#0`````#ZS*&XM,)##'1"0\````
M``G5BU0D8`'IB4PD2(E,)#")\0^L^`+!X1Z+="1`B<T)Q8M$)"`)ZHEL)&B)
M;"0X(="+5"0HB<<AZ@G7`[0D4`(``(M4)#2)^8GP!=R\&X\!P8M$)#")RXG&
M#ZS0&XM4)"3!Y@6)1"1`BVPD0(M$)"`)]0'KB<$Q_P^LT`+!X1Z+5"0LBVPD
M:`G!BT0D*`.$)%@"```3E"1<`@``B5PD8(G>B4PD0`76P6+*@](`,<V)1"0@
MB50D)(M4)$B)V#'JB=$#3"0@P>`%B40D((G8BVPD(`^L^!N+5"0TBUPD0(E$
M)"@+;"0HBT0D,,=$)"0``````>F)3"0@B4PD2(G!P>$>#ZS0`HG-BU0D/`G%
MBT0D.`.$)&`"```3E"1D`@``B6PD.`76P6+*@](`,>N+;"1@,=TQVXGI`<&+
M1"0@$=.+5"0DB4PD*(E<)"R)\\=$)"P`````B<'!X06)3"0PB=&+;"0PB<(/
MK,H;BTPD*`G5B?(!Z<'B'HG5BY0D:`(``(E,)&`/K/L"B4PD*(M,)$`)W8'"
MUL%BRHG0B6PD0`'(,VPD.(GIBVPD2(M<)"R+5"0DQT0D-`````#'1"0D````
M`#'-BTPD*(GN`<:)R,'@!8E$)#"+1"0@BVPD,`^LV1N)\XMT)$`)S8G!`>O!
MX1X/K-`"B<V+E"1P`@``B5PD,`G%BT0D.(M\)#");"0XB5PD2('"UL%BR@'0
M,>Z+;"1@BU0D+#'UB>F+;"0T`<&)^,'@!8E$)""+="0@#ZSO&XM$)"@)_@'Q
MBW0D.(E,)"")3"1@B<'!X1X/K-`"B<V+C"1X`@``BU0D)`G%BT0D0(GOB?6!
MP=;!8LJ)?"0X`<@Q_3-L)$B)Z0'!BT0D(,'@!8G'BT0D(`^LT!N)1"0HBVPD
M*(M$)#"+5"0TQT0D+`````#'1"0T``````G]`>F)3"1(B4PD*(G!#ZS0`HN4
M)(`"``#!X1Z)S0G%B?"!PM;!8LJ);"1``=`S;"0XBU0D+#-L)&")Z0'!BT0D
M*(G+B<:)QXM$)#C!Y@6)="0PBVPD,`^LUQL)_8M\)"`!ZXML)"3'1"0D````
M`(E<)#")7"1@B?J)_HM\)#0/K.X"P>(>B=6+E"2(`@``"?6+="1`B6PD.('"
MUL%BR@'0,>Z+;"1(,?6+="0PB>F)_0'!B?")]\'@!8E$)""+="0@#ZSO&XM$
M)"@)_@'QB4PD2(E,)"")P8M4)"S!X1Z+?"0XB<W'1"0L``````^LT`*+E"20
M`@``"<6+1"1`B>Z)_8'"UL%BRHET)#@!T#'U,VPD8(M4)"2)Z0'!BT0D((G+
MP>`%B40D*(M$)""+;"0H#ZS0&XM4)#3'1"0T`````(E$)$`+;"1`BT0D,`'K
MB<$/K-`"BY0DF`(``,'A'HE<)"B)S8E<)&`)Q8GX@<+6P6+*B6PD0`'0,VPD
M.(M4)"PS;"1(B>D!P8M$)"B)QHG'P>8%B70D,(ML)#`/K-<;"?V+?"0@`>F+
M;"0DB4PD2(E,)#")^HG^#ZSN`L'B'HG5BY0DH`(``(M$)#@)]8MT)$"+?"0T
MB6PD.,=$)"0`````@<+6P6+*`=`Q[HML)&"+5"0LQT0D+``````Q]8MT)#")
MZ8G]`<&)\(GWB<O!X`6)1"0@BT0D*(MT)"`/K.\;B<$)_HM\)#@!\\'A'@^L
MT`*)S8N4)*@"``")7"0@"<6+1"1`B5PD8(GNB?V!PM;!8LJ)="1H`=`Q]3-L
M)$B+5"0DB>D!P8M$)"#!X`6)1"0HBT0D((ML)"@/K-`;BU0D-(E$)#@+;"0X
MBT0D,`'IB4PD0(E,)"B)P0^LT`*+E"2P`@``P>$>B<T)Q8GX@<+6P6+*B6PD
M.`'0,?4S;"1@BU0D+,=$)#0`````B>D!P8M$)"B)RXG&B<>+1"1HP>8%B70D
M,(ML)#`/K-<;"?V+?"0@`>N+;"0DQT0D)`````")7"0PB5PD2(GZB?Z+?"0T
M#ZSN`L'B'HG5BY0DN`(```GUBW0D.(EL)&B!PM;!8LH!T#'NBVPD0(M4)"PQ
M]8MT)#")Z8G]`<&)\(GWP>`%B40D((MT)"`/K.\;BT0D*`G^BWPD:`'QB4PD
M((E,)&")P<'A'@^LT`*)S8N4),`"```)Q8M$)#B)[HG]@<+6P6+*B70D.`'0
M,?4S;"1(B>D!P8M$)"")R\'@!8E$)"B+1"0@BU0D)(ML)"C'1"0L``````^L
MT!N+5"0TQT0D-`````")1"1`BT0D,`ML)$")P0'KP>$>#ZS0`HN4),@"``")
MS8N,),P"```)Q8E<)$B)7"0HB?B);"1`@<+6P6+*@]$`B<N)T3'2`<@1VC-L
M)#@QVS-L)&")Z0'!BT0D*!'3BU0D+(G&B<>+1"0XP>8%B70D,(ML)#`/K-<;
M,=()_8M\)"`!Z8ML)"01TXE,)#")3"1@B?J)_HM\)#0/K.X"P>(>B5PD9(G5
MBY0DT`(```GUBW0D0(EL)#B!PM;!8LH!T#'NBVPD2#'UBW0D,(GIB?T!P8GP
MB?>)R\'@!8E$)""+="0@BT0D*(M4)"P/K.\;QT0D)`````#'1"0L``````G^
MB<&+?"0X`?/!X1X/K-`"BY0DV`(``(G-BXPDW`(```G%BT0D0(E<)"")7"1(
MB>Z)_8'"UL%BRH/1`(G+B=$QT@'($=HQ]3-L)&`QVXET)&")Z0'!BT0D(!'3
MBU0D),'@!8E$)"B+1"0@BVPD*`^LT!LQTHE$)#@+;"0XBT0D,`'I$=.+5"0T
MB4PD*(E,)$")P8E<)$3!X1X/K-`"BY0DX`(``(G-BXPDY`(```G%B?B);"0X
M@<+6P6+*@]$`B<N)T3'2`<@1VC'U,VPD2#';B>D!P8M$)"@1TXM4)"R)QHG'
MP>8%B70D,(ML)#")W@^LUQN)RS'2BT0D8`G]BWPD(,=$)#0``````>N+;"0D
MQT0D)``````1UHE<)#")7"1(B70D3(GZB?X/K.X"P>(>BWPD0(G5BY0DZ`(`
M``GUBW0D.(EL)&"!PM;!8LH!T#'NBU0D+#'WBW0D,(GYBWPD-`'!B?#!X`6)
M_8GWB40D((MT)"`/K.\;BVPD8`G^B?`!R(E$)""+1"0HB<$/K-`"P>$>BU0D
M,`G!BT0D.(G/BTPD-(G3B7PD0,'C'HG.B5PD*`^DUAX/K,H"P>D"B70D+(GN
MB4PD-(N,)/`"``")5"0P@<'6P6+*`<@Q_C-T)$B)\0'!BT0D(,'@!8G&BT0D
M((M4)"2+7"0H#ZS0&\'J&XE$)#B+?"0XB50D/`GWB?B+?"14`<B)P8M$)!@#
M3"00`T0D(`M<)##'1P0`````QT<,`````,='%`````#'1QP`````B0_'1R0`
M````B4<(B=@#!"2)1Q"+1"1``T0D"(E'&(GH`T0D6(E'((N$)/P"``!E,P44
M````=0N!Q`P#``!;7E]=P^BQ(```D%575E/H%]?__X'#IXT``(/L'(7`#X2>
M````BXL<`0``BPF%R8E,)`@/A(H````/M@B$R70%@/D]=48Q]HM\)`B++X7M
M="^)5"0,B40D!&:0@^P$5O]T)`Q5Z++3__^#Q!"%P'4'@'PU`#UT+(/'!(LO
MA>UUVX/$'(GH6UY?7<.0B<:#Q@$/M@Z$R70%@/D]=?$IQNNGC78`B?HK5"0(
MBT0D#(UL-0'!^@*)$(/$'(GH6UY?7<.-=@`Q[>NYC70F`%=6B<93Z$_7__^!
MPN:,``"#[!"+NAP!``"-7"0(9:$4````B40D##'`B=J)\.@.____A<!T,XM4
M)`B+!XT$D(M0!(72B1!TX9"-M"8`````@\`$BU`$A=*)$'7TB=J)\.C;_O__
MA<!US8M$)`QE,P44````=0>#Q!!;7E_#Z&X?``"-M"8`````C;PG`````%57
MB<564XG6Z,/5__^!PU.,``"#[#AEH10```")1"0H,<`QP(`Z/0^4P`'&5N@^
MT?__@\00B00DB>B-5"08Z&W^__^%P`^$#0$``(/L#(G'4.@:T?__@\00.P0D
M#X/>````BT0D&(T,A0````"+@QP!``")1"0$#[9%`(3`#X2E`0``/#T/A)T!
M``")Z.L&D(#Z/70*@\`!#[80A-)U\2GHBU0D!(/L#(LZ`<^+3"0,C40(`E#H
M5M'__X/$$(7`B0</A'4!``"+5"0$C4T!BP*+5"08BQ20#[9%`#P]B`)T(X3`
M=0_K'8GVC;PG`````#P]=!"#P0$/MD'_@\(!A,"(`G7LQ@(],<"-M"8`````
M#[8,!HA,`@&#P`&$R77Q,<"+7"0<93,=%`````^%%`$``(/$+%M>7UW#C;8`
M````@\8!#[9&_X/'`83`B$?_=>_KS)"-="8`BX,<`0``BQ")1"0$BSJ%_P^$
MP@```#'`ZPB-M@````")^(UX`8L,NH7)=?2-!(4,````BXMP$0``A<EU:XE4
M)`B#[`S'@W`1```!````4.ADT/__@\00A<`/A(4```"-#+T`````@^P$48M4
M)!")3"044HE$)!10Z)O0__^+3"04BT0D&(/$$(D!BTPD#(M$)`C'1+@$````
M`(E\)!CI?/[__Y"-="8`@^P(4%+H]LW__XM,)!2)1"08@\00A<")`70AC0R]
M`````.O"C70F`#'`Z7+^__^0N`@````Q_^E/____N/_____IV_[__^@5'0``
MD(UT)@!55XG%5E/H==/__X'#!8H``('LC````&6A%````(E$)'PQP(7M=`:`
M?0``=2.+1"1\93,%%`````^%)P$``('$C````%M>7UW#C;0F`````(/L#%7H
M9\[__XE$)!"#Q!"%P'3)C8,QD___B40D!(V#,)/__XE$)`B#[`S_="0,Z'S.
M__^#Q!"%P`^$L0```(U0$XM\)`2Y`@```(G6\Z9TUXM\)`BY`P```(G6\Z9T
MR(E4)`R#[`Q5Z&/.__^+5"0<B<:)%"2)5"0<Z%'.__^-1`8"B00DZ.7.__^)
MQEA:BU0D%(V#,Y/__U)54&K_:@%6Z%K/__^#Q!R-1"0@4%9J`^BZS/__@\00
M@_C_=!"+1"0L)0#P```]`$```'0^@^P,5N@)SO__@\00@^P,5NA=S?__@\00
MZ3W___^0C70F`(/L#/]T)`SH-,[__XDL).B<SO__@\00Z='^__^)\.B=_O__
MZ\7HIAL``(VV`````%93B<;H!]+__X'#EX@``(/L>&6A%````(E$)'`QP(U$
M)!!05FH#Z`7-__^#Q!"%P'4NBU0D'('B`/```('Z`$```'0D@?H`H```=!R+
M3"1L93,-%````'4G@\1T6U[#D#'`Z^B-="8`@^P(:@)6Z,W,__^#Q!"%P`^4
MP`^VP.O,Z!L;``"-="8`C;PG`````%57B<=64^AUT?__@<,%B```@>PP$```
M9:$4````B80D(!```#'`B50D#&C_#P``C8,YD___C70D)%90Z-#-__^#Q!"%
MP`^.C0```(UH_XN3_````(!\+!P`BQ)T4XG%B50D#(/L!%5J+U;H\<W__X/$
M$(7`BU0D#'0^@^P,4NC=R___55974.C$S/__@\0@BX0D'!```&4S!10```!U
M0X'$+!```%M>7UW#C;8`````A>UUJXUT)@"#[`Q2Z)_+__^#Q`S_="0,5U#H
M8<O__X/$$.N[C70F`(N#_````(L0Z];H*1H``(GVC;PG`````%/HBM#__X'#
M&H<``(/L%(N#_````/\PZ%3+__^-DRR5__]2C9-(D____[,0`0``4E#H:LW_
M_X/$*%O#D(UT)@!64^A)T/__@</9A@``@^P0B[/\````_S;H$\O__XD$).B;
M____6/\VZ`/+__]:C9/=E/__66H`4E*-DU".__]2C9-DD___4E#H8\O__X/$
M)%M>PXVV`````(V\)P````!55U93Z.?/__^!PW>&``"![!P@``!EH10```")
MA"0,(```,<#HA\G__XV31)/__X/L"%)0C8-YD___4&@!$```:@&-="0F5NAT
MS/__@\0<:``0``"-O"03$```5U;H'LS__X/$$(7`>$>)QHU``8/L#%#HN<O_
M_X/$$(7`B<5T$X/L!%974.CURO__QD0U``"#Q!"+C"0,(```93,-%````(GH
M=0^!Q!P@``!;7E]=PS'MZ]_HQQ@``(VT)@````#I.____XUT)@"-O"<`````
M55=64^@7S___@<.GA0``@>R<$```9:$4````B80DC!```#'`C40D+(N\)+`0
M``"+M"2T$```B40D%(G"C8.%D___B7PD#.BU]___@^P(B<5J+U?H&,G__X/$
M$(7`=#F+?"0,C8..D___B?KHX/C__XGXBY0DC!```&4S%10````/A7H!``"!
MQ)P0``!;7E]=PXVT)@````"#[`S_="08Z!S*__]:68E$)""-@YN3__^)1"08
M4%;HY<K__X/$$(7`B<9TFX`^`(V#,9/__XE$)!P/A,X```")]HV\)P````"%
M[705@^P(5E7H<LO__X/$$(7`#X2(````@^P,5NB^R?__@\00@'P&_R]U$HUT
M)@"#Z`&`?`;_+\8$!@!T\HM,)!B-1`@!/?\/```/CR[___^-@YV3__^#[`3_
M="004(V#F)3__U90:``0``!J`8VT)*@```!6Z)7*__^#Q!S_="085FH#Z/;'
M__^#Q!"%P'40BT0D/"4`\```/0"```!T3X/L"/]T)!AJ`.@1RO__@\00A<")
MQ@^$P_[__X`^``^%.____X7M=!>+?"0<N0(```")[O.F=,F0C;0F`````(MT
M)!RX`0```.E0____9I"#[`AJ`5;H=<C__X/$$(7`=9^-@XZ3__^)\NAA]___
M@^P,5NA8RO__@\00Z7+^___HJQ8``(UT)@"-O"<`````BU0D!`^V"HG0A,ET
M&XUV`(/"`8#Y+P^V"@]$PH3)=?#SPXVV`````//#C;8`````5E/HV<S__X'#
M:8,``(/L%(MT)""%]G0X#[86A-)T,8A4)`^#[`Q6Z%3(__^-1`;_@\00#[94
M)`\YQG(+ZSYFD(/H`3G&=#F`."]T].LG9I"-@S&3__^#[`Q0Z+')__^#Q!"#
MQ!1;7L.0C;0F`````(`X+W0P@^@!.<9R]#G&=26`^B]TRXV#G9/__X/L#%#H
M?,G__X/$$.O)C;0F`````(`X+W4'@^@!.<9R]"GPC5`"@?H`$```=R>#P`%H
M`!```%!6C;-P`0``5N@1QO__@\00B?"#Q!1;7L.-M@`````QP.E[____B?:-
MO"<`````5U93Z.C+__^!PWB"``"#[#!EH10```")1"0L,<"+@PB5__^-="0$
MB40D"HN##)7__XE$)`Z+@Q"5__^)1"02BX,4E?__B40D%HN#&)7__XE$)!J+
M@QR5__^)1"0>BX,@E?__B40D(HN#))7__XE$)"8/MX,HE?__9HE$)"J-@Y^3
M___H"/7__XV#J)/__^C]]/__C8.PD___Z/+T__^-@[F3___HY_3__XV#P)/_
M_^C<]/__C8/0D___Z-'T__^-@X63___HQO3__XV#W)/__^B[]/__C8/FD___
MZ+#T__^-@_"3___HI?3__XV#CI/__^B:]/__C8/ZD___B?+HS?/__X7`=`V)
MPHV#YI/__^@,]?__C8,+E/__B?+HK_/__X7`=`V)PHV#'93__^CN]/__C8,H
ME/__B?+HD?/__X7`=#6)PHV#A9/__^C0]/__C9-4E/__C8/`D___Z+_T__^+
M1"0L93,%%````'51@\0P6UY?PXUV`(V#.)3__XGRZ$OS__^%P'4GC70D&XV[
M293__[D*````\Z9UM(U4)"6-@]R3___H=?3__^NCC78`B<*-@]R3___H8_3_
M_^N1Z+P3``"-M@````"-OP````!3Z!K*__^!PZJ```"#[!AEH10```")1"0,
M,<"+@S@!``"#^/]T&HM,)`QE,PT4````=3Z#Q!A;PY"-M"8`````C50D"(V#
MW)/__^BQ\O__B<(QP(72=!(/MA*`^C`/E<$QP(32#Y7`(<B)@S@!``#KM>@Z
M$P``C78`C;PG`````%/HFLG__X'#*H```(/L".ALQ?__@^P,4.A#Q?__@\00
MA<!T#(L`@\0(6\.0C70F`#'`Z_*-M@````"-OP````!55U93Z%?)__^!P^=_
M``"#[!QEH10```")1"0,,<"-5"0(C8-6E/__BWPD,.@/\O__A<!T:X`X`(G&
M=&2#[`A74.A*Q?__@\00A<!U8(/L#%?HJL3__XG%B30DZ*#$__^-1`4"B00D
MZ#3%__^)Q8V#FY/__X/$#%90C8.8E/__5U!J_VH!5>BEQ?__C8-6E/__@\0@
MB>KH]?+__^L0C78`C8-6E/__B?KHX_+__XM$)`QE,P44````=0B#Q!Q;7E]=
MP^@I$@``B?:-O"<`````55=64^B`R?__@<(7?P``@>R,@0``BX0DH($``(G1
MB50D!(UT)#"-F6:4___'A"28`````````,>$)+P`````````QX0DI```````
M``")1"00B9PDG````&6A%````(F$)'R!```QP(V"<I3__XF$))````"-@C&3
M__^-DAV4__^)A"24````C8$6E/__B50D#(F4)*@```")\HF$)*P```"-@7>4
M__^)A"2P````C8$SE/__B80DM````(V!?Y3__XF$)+@```"-@8.4__^)A"2@
M````C8&%D___Z)#P__^%P'0)@#@`#X5S`@``Z/[]__^%P(G%#X2T`@``@^P,
M58M\)!2)^^@EP___C40``8D$).BYP___B40D&(/$$(!]``!T1HM$)`2+?"0(
MB70D&(V`C)3__XG^B<>-M@`````/MD4`@^P,@\4!4%=J_VH!5HM<)"2#Q@+H
M`\3__X/$((!]``!UVHMT)!B-G"2H````BT0D#.L6B?:-O"<`````@\,$BP.%
MP`^$@P$``(GRZ-SO__^%P(G'=.:`.`!TX>C<]/__A<!TV(/L#%>+7"04Z`O$
M__^#Q!"%P(G%#X1.`0``C;8`````B>B+"(/`!(V1__[^_O?1(<J!XH"`@(!T
MZ8G1P>D0]\*`@```#T31C4@"#T3!B=$`T8M,)`B#V`,IZ(L9@\$$C9/__O[^
M]],AVH'B@("`@'3IB=/!ZQ#WPH"````/1-.-60(/1,N)TP#3@]D#*TPD"(/L
M#(V\"`0$``!7BUPD%.B$PO___W0D&(M,)!B)PHV!D93__XG+4(V!G9/__XE$
M)#!0C8&6E/__55!J_VH!B50D-%+HX,+__X/$*&C``0``_W0D%.C/O___@\00
M@_C_=1#HHK___XL`@_@1#X6_"0``@^P$5O]T)!!J`XM<)!3H],#__X/$$(7`
MB<5U%(M$)$`E`/```#T`0```#X1'`0``@^P,_W0D%(M$)"#_,(M<)!B-@W25
M__]0BX,8`0``:@'_,.BPO___@\0@QT0D#`````#K>XUV`#'_C;8`````BYR\
MD````(7;=#6`.P!T,(G8@\<!Z$[S__^%P'3B@^P,4XM<)!3H?<+__X/$$(7`
M=,Z)Q>EW_O__C;0F`````#'MZ6G^__^0@^P,4(E$)!CHP_O__XM$)!B+7"04
MB00DZ$/"__^)1"0<@\00C70F`(N4)'R!``!E,Q44````BT0D#`^%O`D``('$
MC($``%M>7UW#D(UT)@")V#'_A<!T)I"-M"8`````B?*#QP'HINW__X7`=`6`
M.`!U+8N$O)P```"%P'7B@^P,:@V+?"04B?N-KVN4___HW,#__XE$)!B#Q!#I
M)/W__X/L#%"+7"04Z+/!__^#Q!"%P'2_B<7IX?S__Y"-="8`BT0D2(M<)`2)
M1"0,Z#_`__\Y1"0,#X6>_O__BT0D0"7_`0``/<`!```/A8K^__^#[`Q7BWPD
M%(G[Z'+`__^)1"0<C8=AE/__B?+H`>W__X/$$(7`#X2&`0``@^P,4(M<)!3H
M.<'__UI94(M$)!S_,.C;]/__B40D+(/$$(7`#X1<`0``@^P,BW0D*%:+?"04
MB?OH>;___X/$$(/X`W8QB?.-OY^4__^-=`;\N04```#SIG4<@_@$#X0#!P``
M@'P#^R\/A/@&``"0C;0F`````.A[^?__A<!U(8/L"&H`_W0D*(M<)!3HA<#_
M_XE$)"R#Q!"%P`^%]@```(M\)`2-EU24__^-M]V4__^-A]R3__^)^^B)[?__
MZ!2]__]64(V'N)3___]T)"#_="04C;_&E/__4&K_:@'_="0HZ`#`__^#Q"")
M="00BW0D#.M`C78`BUPD!.C'O/__@S@1=4F+7"0$@\4!Z,:\__^#[`S_="0<
M55#_="0P_W0D)%=J_VH!5HM<)#3HMK___X/$,(/L"&C``0``5HM<)!3HH;S_
M_X/$$(/X_W2I@^P,_W0D%(MT)!2)\^C'O?__BUPD'(V&A9/__XG:Z-;L__^)
M'"3H/OG__X/$$.F._?__C;8`````BT0D$(L`B40D'.F5_O__D&H":O]J[HM\
M)"A7BW0D%(GSZ-J\__^#Q`QJ!HV$)(0!``")1"084%?H0[W__X/$$("\)'P!
M````=0Z`O"1]`0``0P^$908``&H`:@!J`/]T)"B+7"04Z)6\___'A"30````
M`2-%9\>$)-0`````````QX0DV````(FKS>_'A"3<`````````,>$).````#^
MW+J8QX0DY`````````#'A"3H````=E0R$,>$).P`````````QX0D\````/#A
MTL/'A"3T`````````,>$)/@`````````QX0D_`````````#'A"0``0``````
M`,>$)`0!````````QX0D2`$```````"#Q!"-A"3`````B40D+(V$)/@```")
M1"0HC;0F`````(/L!&@`@```_W0D&/]T)"B+7"04Z#>\__^#Q!"%P(G%#X[R
M`0``B[0DZ````(N\).P```")Z(GKP>`#B>G!^Q^)?"0D`?"#?"0D`(ET)""+
MO"3T````B[0D\````'<&.40D('8&@\8!@]<`B80DZ````(G(B=H/K-@=P>H=
MQX0D[``````````!QHN$)#@!```1UXFT)/````")O"3T````A<`/A%\!``"_
M0````"G'.?T/3OT#1"0H@^P$5_]T)!A0BUPD%.@EO/__BX0D2`$```'XB80D
M2`$``(/$$(/X0`^%&?___XM$)"PI_0-\)!#H:L'__XUV`(V\)P````"#_3\/
MCMD```"#[4")[L'N!HU>`8ET)""+="0LP>,&`?N-M"8`````BP>#QT")A"3X
M````BT?$B80D_````(M'R(F$)``!``"+1\R)A"0$`0``BT?0B80D"`$``(M'
MU(F$)`P!``"+1]B)A"00`0``BT?<B80D%`$``(M'X(F$)!@!``"+1^2)A"0<
M`0``BT?HB80D(`$``(M'[(F$)"0!``"+1_")A"0H`0``BT?TB80D+`$``(M'
M^(F$)#`!``"+1_R)A"0T`0``B?#HC\#__SG?#X5/____BW0D(,'F!BGU:D15
M5_]T)#2+7"04Z#VZ__^)K"1(`0``@\00Z?[]__^-M@````"+?"00Z>_^__^-
MM"8`````@^P,_W0D*(M<)!3H2+O__XN$)``!``"+G"3X````B[0D_````(N4
M)`0!``")1"0@B=@/K/`#B50D)(/@/XU0`<:$!`@!``"`@\00@_HX#X^5`@``
MN#@````Q_RG0`U0D*(/X!`^#TP(``(7`=`NH`L8"``^%CP,``(M\)!"+;"04
MB+PD-@$``(B<)#<!``")^`^LZ!B(A"0P`0``B?@/K.@0B(0D,0$``(GXB*0D
M,@$``(B$)#,!``")V`^L\!B(A"0T`0``B=@/K/`0B(0D-0$``(M$)"SH;+__
M_XNT),````"+O"3$````BU0D!(GQ#ZSY&(V2C)3__XB,)#\!```/ML&)\0^L
M^1"+O"3,````B(PD0`$``(GQB[0DR````(BL)$$!``"(C"1"`0``B?$/K/D8
MB(PD0P$``(GQ#ZSY$(N\)-0```"(C"1$`0``B?&+M"30````B*PD10$``(B,
M)$8!``")\0^L^1B(C"1'`0``B?$/K/D0B[PDW````(B,)$@!``")\8NT)-@`
M``"(K"1)`0``B(PD2@$``(GQ#ZSY&(B,)$L!``")\0^L^1"+O"3D````B(PD
M3`$``(GQB[0DX````(BL)$T!``"(C"1.`0``B?$/K/D8B(PD3P$``(GQ#ZSY
M$(V\)'L!``"(C"10`0``B?&-M"1``0``B*PD40$``(B,)%(!``"-C"13`0``
MB4PD'(G-B7PD$(GWB=;I#0```(VT)@`````/M@>#QP&#[`Q05FK_:@%5BUPD
M)(/%`NC,N?__@\0@.6PD$'7;BUPD!,:$)'L!````C8/=E/__4(V#J93___]T
M)"#_="0@_W0D%%!J_VH!_W0D*.B0N?__@\0@Z>_Y__^0C;0F`````(M$)!"+
M4`2%T@^$`?G__X/L#%*+?"04B50D((G[Z"ZX__^#Q!"#^`,/AN+X__^+5"00
MC;^DE/__N04```"-=`+\\Z8/150D'(E4)!SIO_C__XM,)"BX0`````'1*=!T
M#3'2Q@01`(/"`3G"<O6+1"0LZ#J]__^+?"0HN0X````QP/.KZ5G]__^#[`A0
M_W0D%(M$)"#_,(M<)!B-@SB5___I:_;__XU*!,<"`````,=$`OP`````@^'\
M*<H!PH/B_(/Z!`^"&/W__X/B_#'`B3P!@\`$.=!R]ND$_?__@+PD?@$``$$/
MA8WY__^`O"1_`0``0P^%?_G__X"\)(`!``!(#X5Q^?__@+PD@0$``$4/A6/Y
M__]J`FK_:L:+;"0H58MT)!2)\^CUM?__@\0,:BF+?"085U7H9;;__XV&W93_
M_U"-AJF4__]7_W0D,/]T)"10:O]J`?]T)#CH(;C__X/$,.F`^/__B?:-O"<`
M````,<EFB4P"_NEE_/__Z+\$``#K#9"0D)"0D)"0D)"0D)!55U93Z!>[__^!
MPZ=Q``"#[#B+N_P```!EH10```")1"0H,<#_-^C5M?__7?\WB<;HR[7__P^V
M5FB(4&F-1"0HB40D'(G"C8/`D___Z*_C__^#Q!"%P'0)@#@Q#X2O`@``Z,KN
M__^#[`S_-^B0M?__C9/7E/__:@MJ`5)0Z#^U__^#Q""%P`^$_@```(M`#(.[
M>!$```&++XM`&(E$)`@/CN<````Q]NL]C;0F`````(M"#(/L"(U6`5"+@W01
M``#_-)")5"04Z)2W__^#Q!"%P(N+>!$``'5OBU0D!(U"`8G6.<%^8H/L#%7H
M$;7__VH`5O]T)"!0Z!2V__^#Q""%P'0]BQ"++XM"""4`!"``/0`$``!TFHE4
M)`2#[`Q5Z-VT__]J`FH`BU0D'%)0Z$ZW__^++X/$(.EW____C70F`(N+>!$`
M`(LOC4'_.?!U/8/Y`7XXB>B^`0```(ML)`CK"8VT)@````"+!X/L#(/&`5#H
MBK3__UI955#H,;3__X/$$#FS>!$``'_>BR^#[`Q5Z&NT__^-D]R4__]J`VH!
M4E#H&K3__X/$((7`B<9T,HM`#(/L#(LH_S?H0K3__XV3WI3__X/$#%)54.@!
MM/__BT8,@\00BS#V1@I`#X5O`0``@^P,_S?H%;3__XV3XY3__VH#:@%24.C$
ML___@\0@A<")QG0VBU0D#(V#CI/__^CLX?__A<")Q0^$`@$``(M&#(/L#(LP
M_S?HT[/__X/$#%564.B8L___@\00@^P,_S?HN[/__XV3Y93__X/$#&H!4E#H
MN;+__XG&6/\WZ)^S__^-D_J4__^#Q`Q25E#H7K/__UK_-^B&L___BU0D',9`
M:0"-@X63___H<^'__X/$$(7`B<:)@WP1``!T1(/L"&C``0``5NA&LO__C5`!
M@\00@_H!=@F#^!$/A;(```"+1"0<93,%%`````^%G````(/$+%M>7UW#B?:-
MO"<`````@^P,_[-T$0``Z*+O__^#Q!"%P(G&B8-\$0``=9^-@\B5__^#[`Q0
MZ,2T__^-="8`@'@!``^$3/W__^E"_?__D(N#=!$``(/L#(LHBT8,BS#_-^C)
MLO__B>J)\.A@YO__@\00Z?/^__^0C;0F`````(/L#/\WZ*:R__]97590Z`VT
M__^#Q!#I=O[__^A``0``4(N#=!$``%;_,(V#[)7__U#H2K3__XUV`(V\)P``
M``!75E.+7"00Z&,```"!QQ1N``"#[`Q3Z)7J__\/MA"#Q!")QH32=!F)]HV\
M)P````"#P`&`^B\/MA`/1/"$TG7PZ"OM__^%VW08A<!T%(`[`'0/C;^1E/__
MN00```#SIG0$6UY?PXG86UY?Z:'C__^+/"3#9I!FD&:09I!FD&:0D%/H"K?_
M_X'#FFT``(/L"/^S-`$``/]T)!S_="0<_W0D'.A*L?__@\086\-FD&:0D%57
M5E/HU[;__X'#9VT``(/L#(ML)"B-L]S^___H.[#__XV#V/[__RG&P?X"A?9T
M)3'_C;8`````@^P$5?]T)"S_="0L_Y2[V/[__X/'`8/$$#G^=>.#Q`Q;7E]=
MPXUV`//#9I!FD&:09I!FD&:09I!3Z&JV__^!P_IL``"#[`CHO++__U.#[`CH
M4[;__X'#XVP``(/$"%O#`P````$``@`N+@`E<R\E<P`O<')O8R]S96QF+V5X
M90!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z
M.D)/3U0`+W!R;V,O)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!0
M15),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:
M140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`
M4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2
M`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`
M,0!,1%],24)205)97U!!5$@`55-%4@!365-414T`+W1M<`!414U01$E2`%1-
M4`!54T523D%-10`E,#)X`'!A<BT`)7,E<R5S)7,`<&%R;``N<&%R`"5S)7-C
M86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6
M`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#0U`"UE`"TM````
M7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````<&5R;'AS:2YC
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O
M<&5R871I;VXI"@``56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@````!E=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E
M;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?
M0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO
M=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD
M9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T
M96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>
M3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I4
M14U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]
M/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD
M>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@
M)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@
M7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*
M8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I
M;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y
M<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*
M?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D
M("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H
M*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]
M("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z
M)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG
M=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@
M+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H
M*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S
M*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L
M("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U
M9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3([
M"FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF
M("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I
M92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E
M860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I
M;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F
M<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@
M:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^
M(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X
M(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E
M="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M
M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A
M=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@
M/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN
M*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B
M=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E
M9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I
M*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F
M+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@
M)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@
M/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI
M8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA
M;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*
M;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E
M7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD
M9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@
M/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L
M($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U
M<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`]
M(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME
M>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S
M("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U
M<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L
M92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE
M.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D
M:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U
M9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@
M)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@
M)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M
M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H
M)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D
M.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY
M("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*
M=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T10
M04XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E
M("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL
M96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@
M(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*
M;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C
M:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET
M:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@
M/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O
M<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM
M>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL
M7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF
M>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I
M('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`
M05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D
M9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)
M34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2![
M"G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*
M979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@
M0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D
M,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*
M96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@
M*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I
M('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@
M;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N
M86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T
M7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC
M*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I
M('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`
M05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*
M?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`[
M"FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B
M0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H
M)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z
M("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@
M/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ
M7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>
M("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H
M9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D
M(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!
M4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T
M95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)
M3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)
M3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D
M92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S
M(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R
M(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]
M?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO
M861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@
M>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D
M=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!
M4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H
M)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M
M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E
M="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*
M:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D
M=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH
M)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[
M87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB
M97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$
M>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY
M("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I
M='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L
M("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]
M("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA
M<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO
M;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("10
M05(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@
M/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L*
M*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]
M"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD
M;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN
M7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL
M(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD*
M*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@
M)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@
M;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D[
M"B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI
M)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD
M8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@
M(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C
M:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT
M9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N
M=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^
M=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]
M('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H
M,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ
M4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I
M9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$
M:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@
M97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^
M861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C
M='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N
M86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C
M:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*
M)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M
M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D
M;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO
M<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!0
M05(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E
M($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@
M/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*
M)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B
M.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@
M0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q
M*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H
M:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@
M*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?
M;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R
M7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R
M<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO
M72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M
M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R
M86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB
M97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D
M;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S
M=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB
M97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14
M;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M
M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8[
M"E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE
M(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM
M3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"![
M"FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@
M*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I
M;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@[
M"D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@
M(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE
M<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@
M:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E
M<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y
M.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z
M.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A
M='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I
M<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@
M<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q
M=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![
M(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@
M)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@
M5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@
M>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@
M+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F
M:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS
M,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E
M<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%
M4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE
M(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E
M;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB
M+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@
M;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H
M+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP
M+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B
M=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D
M<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@
M?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S
M:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B
M*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F
M:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@
M)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%
M04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B
M.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%
M35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP
M9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@
M)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U
M;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N
M(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D
M=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N
M=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I
M;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N
M;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S
M971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE
M(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!]
M(&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2![
M"B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!2
M3T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E
M>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]
M"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1
M)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z
M.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ
M1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W
M9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]
M7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*
M)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$
M(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@
M*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$
M25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?
M7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE
M=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%2
M7T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE
M86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@
M)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O
M=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D
M;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@
M:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E
M9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X
M<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C
M:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@
M4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O
M<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L
M('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R
M>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z
M.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z
M.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?
M7PH``1L#._`````=````K'#__PP!``!\=/__,`$``(QT__\,#0``#'C__T0!
M``#LG___B`$``*R@___L`0``/*'__R0"``",H___I`(``/RD__]<`P``C*7_
M_ZP#``!\IO__2`0``+RF__]X!```'*?__\0$``#<I___5`4``.RG__]H!0``
M_*G__U`&```LJO__9`8``!RK___(!@``[*S__P`'``!LK?__)`<``*RM__]0
M!P``?*[__[P'``#LN___4`L``'R____$#```Z[___U0-``#\O___:`T``"S`
M__^4#0``C,#__^`-``"<P/__]`T``!0``````````7I2``%\"`$;#`0$B`$`
M`"`````<````F&___]`#````#@A&#@Q*#PMT!'@`/QH[*C(D(A````!`````
M1'/__Q``````````0````%0```#`=O__WR<```!!#@B%`D$.#(<#1`X0A@1!
M#A2#!48.H`8#R"<*#A1!PPX00<8.#$''#@A!Q0X$00L```!@````F````%R>
M__^\`````$$."(4"00X,AP-!#A"&!$$.%(,%3@XP`D$.-$$..$0./$$.0$@.
M,%<*#A1#PPX00<8.#$''#@A!Q0X$0@MN"@X40\,.$$'&#@Q!QPX(0<4.!$0+
M-````/P```"XGO__@@````!!#@B'`D$.#(8#0PX0@P1.#B`"9@H.$$'##@Q!
MQ@X(0<<.!$$+``!\````-`$``!"?__]+`@```$$."(4"00X,AP-##A"&!$$.
M%(,%4`Y,5PY02`Y`60Y,0PY02`Y``D\.3$T.4$@.0`)X"@X40<,.$$'&#@Q!
MQPX(0<4.!$<+`EP.3$L.4$@.0%(.1$$.2$D.3$4.4%`.0&,.2$$.3$$.4%`.
M0````+0```"T`0``X*#__VH!````00X(A0)!#@R'`T,.$(8$00X4@P51#J`!
M;0H.%$'##A!!Q@X,0<<."$'%#@1("T,.K`%!#K`!3`Z@`5L.K`%$#K`!2`Z@
M`7`.K`%!#K`!9@ZL`4$.J`%+#JP!00ZP`4$.M`%"#K@!0@Z\`4$.P`%(#J0!
M10ZH`4$.K`%"#K`!2`Z@`5@.K`%!#K`!2`Z@`4,.K`%!#K`!2`Z@`4T.K`%$
M#K`!4`Z@`0!,````;`(``)BA__^%`````$$."(8"00X,@P-0#H0!40Z(`4$.
MC`%"#I`!2`Z``6X*#@Q!PPX(0<8.!$(+2PZ(`4(.C`%!#I`!2`Z``0```)@`
M``"\`@``V*'__^<`````00X(A0)!#@R'`T,.$(8$00X4@P51#L0@6`[(($L.
MS"!!#M`@2`[`(&,.Q"!!#L@@0@[,($$.T"!(#L`@2P[,($$.T"!&#M0@00[8
M($$.W"!!#N`@2`[`(%8*#A1!PPX00<8.#$''#@A!Q0X$1PM+#LP@00[0($@.
MQ"!$#L@@00[,($$.T"!(#L`@`"P```!8`P``+*+__SL`````00X(@P).#AQ(
M#B!,#B1,#BA!#BQ!#C!(#@A!PPX$`$@```"(`P``/*+__U,`````00X(A@)!
M#@R#`TX.'$@.($X.'$(.($8.'$<.&$(.'$$.($$.)$<.*$<.+$$.,$@.#$'#
M#@A!Q@X$``",````U`,``%"B__^Y`````$$."(4"00X,AP-!#A"&!$$.%(,%
M40ZP0%T.N$!!#KQ`00[`0$<.Q$!%#LA`0@[,0$4.T$!(#K1`10ZX0$@.O$!!
M#L!`2`ZP0$P.O$!!#L!`2`ZP0$D.M$!!#KA`00Z\0$$.P$!-#K!`6`H.%$'#
M#A!!Q@X,0<<."$'%#@1!"P`0````9`0``("B__\%`````````.0```!X!```
M?*+__P4"````00X(A0)!#@R'`T$.$(8$00X4@P51#K`A>0ZX(40.O"%!#L`A
M2`ZP(7$*#A1!PPX00<8.#$''#@A!Q0X$2`M##KPA1`[`(48.O"%!#K@A3PZ\
M(4$.P"%(#K`A:0ZX(4$.O"%!#L`A2`ZP(4L.O"%!#L`A2`ZP(74.M"%$#K@A
M00Z\(4<.P"%!#L0A10[((4(.S"%(#M`A2`ZT(40.N"%!#KPA0@[`(4@.L"%7
M#K@A1`Z\(4(.P"%(#K`A`D$.N"%"#KPA00[`(4@.L"%4#KPA00[`(4@.L"$0
M````8`4``*2C__\J`````````&````!T!0``P*/__^<`````00X(A@)!#@R#
M`TX.(%8.+$$.,$P.(&8.+$$.,$@.($,*#@Q!PPX(0<8.!$D+7@XL00XP2`X@
M:@XD00XH00XL1PXP2`X@10H.#$'##@A!Q@X$1PLT````V`4``$RD___$`0``
M`$$."(<"00X,A@-!#A"#!$X.0`-@`0H.$$'##@Q!Q@X(0<<.!$0+`"`````0
M!@``Y*7__W8`````00X(@P).#B!G"@X(0<,.!$D+`"@````T!@``0*;__S0`
M````00X(@P).#A!(#AQ!#B!(#A!)"@X(0<,.!$8+:````&`&``!4IO__QP``
M``!!#@B%`D$.#(<#00X0A@1!#A2#!4X.,&T..$$./$$.0$@.,$<./$$.0&8.
M-$$..$$./$<.0$$.1$(.2$(.3$$.4$X.,&D*#A1!PPX00<8.#$''#@A!Q0X$
M00L`D`,``,P&``"XIO__80T```!!#@B%`D$.#(<#00X0A@1!#A2#!5$.H(,"
M`NH.K(,"00ZP@P)>#J"#`FD.K(,"1`ZP@P)!#K2#`D(.N(,"0@Z\@P)!#L"#
M`D\.H(,"`DL.K(,"00ZP@P),#J"#`@*##JR#`D@.L(,"30ZT@P)/#KB#`DL.
MO(,"1P[`@P)!#L2#`D(.R(,"0@[,@P)%#M"#`D@.J(,"10ZL@P)$#K"#`D@.
MH(,"6`ZD@P)!#JB#`D0.K(,"0@ZP@P),#J"#`ET.K(,"1`ZP@P)&#K2#`DL.
MN(,"2`Z\@P)"#L"#`D@.H(,"=@ZL@P)!#K"#`DP.H(,"70ZL@P)!#K"#`F`.
MH(,"8@H.%$'##A!!Q@X,0<<."$'%#@1&"W$.K(,"0@ZP@P)8#J"#`D@.K(,"
M00ZP@P),#J"#`@)"#JR#`D$.L(,"7PZ@@P)+#JR#`D$.L(,"2@ZL@P)!#JB#
M`D$.K(,"1@ZP@P),#J"#`DL.K(,"10ZP@P).#J"#`@)"#JB#`D(.K(,"1`ZP
M@P)0#J"#`FL.I(,"00ZH@P)*#JR#`D0.L(,"1PZT@P)"#KB#`D(.O(,"1`[`
M@P)(#J"#`FH.K(,"1`ZP@P)!#K2#`D$.N(,"1`Z\@P)$#L"#`D$.Q(,"0@[(
M@P)"#LR#`D$.T(,"3`Z@@P)##JB#`D4.K(,"00ZP@P),#J"#`D@.K(,"1`ZP
M@P)G#J"#`ET.I(,"0@ZH@P)"#JR#`D4.L(,"3@ZD@P)"#JB#`DP.K(,"00ZP
M@P)(#J"#`EH.I(,"0@ZH@P)"#JR#`D0.L(,"`K$.H(,"8`ZD@P)%#JB#`D0.
MK(,"1`ZP@P),#J"#`@*@#J2#`D$.J(,"1`ZL@P)!#K"#`EP.H(,"`P8!#J2#
M`D$.J(,"00ZL@P)$#K"#`E,.H(,"7@ZL@P)$#K"#`@)$#J"#`@/N`0ZL@P)!
M#K"#`D$.M(,"0@ZX@P)"#KR#`D$.P(,"3PZ@@P)9#J2#`DH.J(,"1`ZL@P)$
M#K"#`D$.M(,"0@ZX@P)"#KR#`D0.P(,"2`Z@@P)?#JR#`D$.L(,"4@Z@@P("
M9@H.J(,"00ZL@P)$#K"#`D8.M(,"3PL"<@ZD@P)"#JB#`D(.K(,"10ZP@P).
M#J2#`D(.J(,"10ZL@P)!#K"#`DP.M(,"1PZX@P)$#KR#`D0.P(,"00[$@P)"
M#LB#`D(.S(,"1`[0@P)(#J"#`G`!``!@"@``E+#__X8#````00X(A0)!#@R'
M`T$.$(8$00X4@P5.#DQ4#E!&#DQ"#E!F#D!5#DQ"#E!-#E1"#EA!#EQ!#F!(
M#D!R#DA$#DQ)#E!,#D!:#DQ!#E!'#E1!#EA$#EQ!#F!(#D!>#DQ!#E!'#E1"
M#EA%#EQ!#F!*#D!V#DQ$#E!&#DQ!#DA!#DQ!#E!(#D!-#DQ!#E!-#E1"#EA!
M#EQ!#F!(#D!,#DQ$#E!.#D1!#DA!#DQ!#E!+#D!/#DQ"#E!-#E1"#EA!#EQ!
M#F!(#D!E#DQ$#E!(#D1!#DA!#DQ!#E!(#D!##DQ"#E!.#D1"#DA!#DQ!#E!(
M#DQ"#E!.#D1!#DA!#DQ!#E!&#DQ"#E!;#D!/#DA%#DQ!#E!+#D!B"@X40<,.
M$$'&#@Q!QPX(0<4.!$H+0PH.3$8.4$@.0%4.3$$.4$D+60Y,20Y040Y`4`Y,
M0@Y01@Y,00Y(00Y,00Y02`Y`2PY$1PY(0@Y,1PY0`$0```#4"P``L++__V\`
M````00X(AP)!#@R&`T$.$(,$4@X<00X@2PX0`D$*PPX,0<8."$''#@1!"T/#
M#@Q!Q@X(0<<.!````$0````<#```>&?__SP"````1`P!`$<0!0)U`$8/`W5P
M!A`'`G5\$`8"=7@0`P)U=`-W`0K!#`$`0<-!QD''0<5##`0$00L``!````!D
M#```C[+__P0`````````*````'@,``",LO__*P````!!#@B#`DX.$$8.%$0.
M&$0.'$0.($@."$'##@1(````I`P``)"R__]=`````$$."(4"00X,AP-!#A"&
M!$$.%(,%3@X@:0XD00XH1`XL1`XP30X@1PX40<,.$$'&#@Q!QPX(0<4.!```
M$````/`,``"DLO__`@`````````8````!`T``*"R__\4`````$$."(,"3@X0
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````,!D`
M`.`8```!`````0````$```#+`0```0```-8!```!````X`$```$````O`@``
M`0```(H#```,````O!$```T```#D80``&0```*C-```;````!````!H```"L
MS0``'`````0```#U_O]OK`$```4```#L"```!@```(P"```*````_`0```L`
M```0````%0`````````#````T,X```(```#@`0``%````!$````7````W`\`
M`!$```!4#P``$@```(@````3````"````!X````(````^___;P$```C^__]O
MM`X``/___V\"````\/__;^@-``#Z__]O!0``````````````````````````
M``````````````````````````````"PS0````````````#V$0``!A(``!82
M```F$@``-A(``$82``!6$@``9A(``'82``"&$@``EA(``*82``"V$@``QA(`
M`-82``#F$@``]A(```83```6$P``)A,``#83``!&$P``5A,``&83``!V$P``
MAA,``)83``"F$P``MA,``,83``#6$P``YA,``/83```&%```%A0``"84```V
M%```1A0``%84``!F%```=A0``(84``"6%```IA0``+84``#&%```UA0``.84
M``#V%```!A4``!85```F%0``-A4``$85``!6%0``9A4``'85``"&%0``EA4`
M`*85````````````````````````````````````````````````````````
M``````````#`%0````````30``#_____`&4``$=#0SH@*$1E8FEA;B`W+C,N
M,"TR,RD@-RXS+C``1T-#.B`H1&5B:6%N(#<N,RXP+3$S*2`W+C,N,```+G-H
M<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M
M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N
M=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G!L="YG;W0`
M+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N
M:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9&%T80`N8G-S`"YC
M;VUM96YT````````````````````````````````````````````````````
M``````L````!`````@```%0!``!4`0``$P```````````````0`````````3
M````!P````(```!H`0``:`$``"````````````````0`````````(0````<`
M```"````B`$``(@!```D```````````````$`````````#0```#V__]O`@``
M`*P!``"L`0``X`````4`````````!`````0````^````"P````(```",`@``
MC`(``&`&```&`````0````0````0````1@````,````"````[`@``.P(``#\
M!``````````````!`````````$X```#___]O`@```.@-``#H#0``S`````4`
M`````````@````(```!;````_O__;P(```"T#@``M`X``*`````&`````@``
M``0`````````:@````D````"````5`\``%0/``"(````!0`````````$````
M"````',````)````0@```-P/``#<#P``X`$```4````6````!`````@```!\
M`````0````8```"\$0``O!$``",```````````````0`````````=P````$`
M```&````X!$``.`1``#0`P`````````````0````!````((````!````!@``
M`+`5``"P%0``$```````````````"`````@```"+`````0````8```#`%0``
MP!4``"1,`````````````!``````````D0````$````&````Y&$``.1A```4
M```````````````$`````````)<````!`````@```/AA``#X80``/#\`````
M````````!`````````"?`````0````(````TH0``-*$``/0`````````````
M``0`````````K0````$````"````**(``"BB```@#0`````````````$````
M`````+<````.`````P```*C-``"HO0``!```````````````!`````0```##
M````#P````,```"LS0``K+T```0```````````````0````$````SP````8`
M```#````L,T``+"]```@`0``!@`````````$````"````(8````!`````P``
M`-#.``#0O@``,`$`````````````!`````0```#8`````0````,`````T```
M`,```!````````````````0`````````W@````@````#````(-```!#````T
M$``````````````@`````````.,````!````,``````````0P```.@``````
M`````````0````$````!`````P``````````````2L```.P`````````````
)``$`````````
